#include <libmp/all.h>
#include <stdio.h>

#include "../callback.h"
#include "../intl.h"
#include "../cmd.h"
#include "../log.h"

bool cmd_sync(lm_ctx_t *ctx, config_t *config, args_t *args){
  bool ret = false, fail = false;
  ssize_t synced = 0;
  char *arg = NULL;
  
  args_split(args, "fail");
  args_register(args, "fail");
  
  if((arg = args_register_check(args)) != NULL){
    error(_("Unknown argument: "FG_BOLD"--%s"FG_RESET", run with "FG_BOLD"--help"FG_RESET" to list the avaliable arguments"), arg);
    return false;
  }

  if(args_get_bool(args, "help")){
    info(_("Usage: " FG_BOLD "sync <options>"));
    info(_("Listing options for the list command:"));
    printf(_("    "FG_BOLD"--fail"FG_RESET":\tquit on a single pool sync failure\n"));
    return true;
  }

  if(config->pool_count == 0){
    error(_("There are no pools specified in the configuration"));
    goto end;
  }

  fail = args_get_bool(args, "fail");
  synced = lm_ctx_sync(ctx, true, callback_sync, &fail);
  bar_free();

  if(synced < 0 && !fail){
    error(_("Failed to sync pools: %s"), lm_strerror());
    goto end;
  }

  else if(synced < 0 && fail)
    goto end;

  info(_("Synced "FG_BOLD"%d"FG_RESET"/"FG_BOLD"%d"FG_RESET" pools"), synced, config->pool_count);
  ret = true;

end:
  bar_free();
  return ret;
}
